==> awsmate-0.3.0.tar.gz: awsmate-0.3.0/CONTRIBUTING.md <==
## Did you find a bug?

* **Ensure the bug was not already reported** by searching on GitHub under [Issues](https://github.com/shlublu/awsmate/issues "awsmate bugtracker").

* If you're unable to find an open issue addressing the problem, [open a new one](https://github.com/shlublu/awsmate/issues/new?assignees=&labels=&template=bug_report.md&title= "new bug report on awsmate bugtracker"). Be sure to include a **title and clear description**, as much relevant information as possible, and a **code sample** demonstrating the expected behavior that is not occurring.

## Did you write a patch that fixes a bug?

* Open a new GitHub pull request with the patch.

* Ensure the PR description clearly describes the problem and solution. Include the relevant issue number if applicable.

* Before submitting, feel free to [open a discussion](https://github.com/shlublu/awsmate/discussions/new/choose "new discussion on awsmate forum") to let us know about your patch, or to ask any question you would like.

## Did you fix whitespace, format code, or make some refactoring?

Such changes are welcome! Please just let us know why this change would be an improvement by filling the PR description.

## Do you intend to add a new feature or change an existing one?

* Suggest your change in the [discussion forum](https://github.com/shlublu/awsmate/discussions/new?category=ideas "new idea on awsmate forum").

* After having collected some feedback, feel free to [open a precise feature request](https://github.com/shlublu/awsmate/issues/new?assignees=&labels=&template=feature_request.md&title= "new feature request on awsmate bugtracker").

## Do you have questions about the source code or the use of the library?

* Ask any question you would like in [the discussion forum](https://github.com/shlublu/awsmate/discussions/new/choose "new discussion on awsmate forum").

## Do you want to contribute to the documentation?

You are very welcome! Please proceed the same way as described above for bug fixing an features requests.

Thank you so much!

Shlublu

*This document has been derived from [Ruby on Rails's guidelines](https://github.com/rails/rails/blob/main/CONTRIBUTING.md "Ruby on Rail CONRIBUTING document")*

==> awsmate-0.4.1.tar.gz: awsmate-0.4.1/CONTRIBUTING.md <==
## Did you find a bug?

* **Ensure the bug was not already reported** by searching on GitHub under [Issues](https://github.com/shlublu/awsmate/issues "awsmate bugtracker").

* If you're unable to find an open issue addressing the problem, [open a new one](https://github.com/shlublu/awsmate/issues/new?assignees=&labels=&template=bug_report.md&title= "new bug report on awsmate bugtracker"). Be sure to include a **title and clear description**, as much relevant information as possible, and a **code sample** demonstrating the expected behavior that is not occurring.

## Did you write a patch that fixes a bug?

* Open a new GitHub pull request with the patch.

* Ensure the PR description clearly describes the problem and solution. Include the relevant issue number if applicable.

* Before submitting, feel free to [open a discussion](https://github.com/shlublu/awsmate/discussions/new/choose "new discussion on awsmate board") to let us know about your patch, or to ask any question you would like.

## Did you fix whitespace, format code, or make some refactoring?

Such changes are welcome! Please just let us know why this change would be an improvement by filling the PR description.

## Do you intend to add a new feature or change an existing one?

* Suggest your change in the [discussion board](https://github.com/shlublu/awsmate/discussions/new?category=ideas "new idea on awsmate board").

* After having collected some feedback, feel free to [open a precise feature request](https://github.com/shlublu/awsmate/issues/new?assignees=&labels=&template=feature_request.md&title= "new feature request on awsmate bugtracker").

## Do you have questions about the source code or the use of the library?

* Ask any question you would like in [the discussion board](https://github.com/shlublu/awsmate/discussions/new/choose "new discussion on awsmate board").

## Do you want to contribute to the documentation?

You are very welcome! Please proceed the same way as described above for bug fixing an features requests.

Thank you so much!

Shlublu

*This document has been derived from [Ruby on Rails's guidelines](https://github.com/rails/rails/blob/main/CONTRIBUTING.md "Ruby on Rail CONRIBUTING document")*
